# 2021-04-18 Weighted Pool

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This factory was superseded by this [updated version (also now deprecated)](../20220908-weighted-pool-v2).

Deployment of the `WeightedPoolFactory`, for Weighted Pools of up to 8 tokens, and `WeightedPool2TokensFactory`, for Weighted Pools restricted to 2 tokens, but with an optional price oracle.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet address](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [Optimism mainnet address](./output/optimism.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`WeightedPoolFactory` artifact](./artifact/WeightedPoolFactory.json)
- [`WeightedPool2TokensFactory` artifact](./artifact/WeightedPool2TokensFactory.json)
